Name: panicsel
%define Version 1.3.8
Version: %Version
Release: 1
Summary: A package that adds additional features to the panic handler.
Copyright: BSD
Group: System Environment/Kernel
Source: panicsel-%Version.tar.gz
#Requires: ipmidrvr
%ifarch x86_pentium3
AutoReqProv: No
%endif

%description
The panicsel kernel module adds an OS Critical Stop message to the BIOS System
Event Log, sends a BMC LAN SNMP Alert, and sets the Telco Critical Alarm
LED when a panic occurs.

The panicsel component package provides utilities to view the SEL (showsel), 
perform a hardware reset (hwreset), and set up the Platform Event Filter 
entry to allow BMC LAN alerts from OS Critical Stop messages (pefconfig).  
It requires an IPMI driver (ipmidrvr) package in order to talk to the 
BMC/firmware interface.
An IPMI driver can be provided by either the Intel IPMI driver (/dev/imb) 
or the valinux IPMI driver (/dev/ipmikcs).

Warning: This rpm makes a change to /etc/lilo.conf for the append= line.
The original file will be saved as /tmp/lilo.conf-orig.

%prep
%setup -q

%build
sh configure
make

%install
RPM_BUILD_ROOT=`pwd`
make DESTDIR=${RPM_BUILD_ROOT} install
( cd ${RPM_BUILD_ROOT}/usr/man/man8; gzip -f *.8 ) 

%files
%defattr(0755,root,root)
/usr/sbin/showsel
/usr/sbin/hwreset
/usr/sbin/sensor
/usr/sbin/pefconfig
/usr/sbin/tmconfig
/usr/sbin/fruconfig
/usr/sbin/alarms
/usr/sbin/wdt
%defattr(0664,root,root)
/usr/share/panicsel/README
/usr/share/panicsel/COPYING
/usr/share/panicsel/UserGuide
/usr/share/panicsel/bmclan.mib
/usr/man/man8/showsel.8.gz
/usr/man/man8/sensor.8.gz
/usr/man/man8/hwreset.8.gz
/usr/man/man8/alarms.8.gz
/usr/man/man8/wdt.8.gz
/usr/man/man8/pefconfig.8.gz
/usr/man/man8/tmconfig.8.gz
/usr/man/man8/fruconfig.8.gz
# %defattr(-,root,root)
# %doc README TODO COPYING ChangeLog

%clean
RPM_BUILD_ROOT=`pwd`
# rm -rf ${RPM_BUILD_ROOT}

%pre
# before install
pdir=/usr/share/panicsel
echo "Installing Panic Handler utilities ..."
mkdir -p $pdir

dev1=/dev/imb
dev2=/dev/ipmikcs
if [ ! -c $dev1 ]
then
  if [ ! -c $dev2 ]
  then
     echo "No IPMI devices found ($dev1 or $dev2)."
     echo "Panic Handler utilities depend on an IPMI driver, aborting."
     exit 1
  fi
fi


%post
# after install
pdir=/usr/sbin
tmped=/tmp/edmk.tmp
tmpsel=/tmp/pefcfg.tmp

echo "panicsel install started `date`" 
# Assumes that the kernel patches are already in place.

# Make sure that the panic timeout is set to some reasonable value
pnew=5
pfil=/proc/sys/kernel/panic
lilofil=/etc/lilo.conf
pval=`cat $pfil`

if [ ! -f $lilofil ]
then
   # They must have grub instead of lilo, so skip this change. 
   pval="1"
fi

# assume that if $pval is set, that someone has already configured lilo.conf
if [ $pval = "0" ]
then
   # Panic timeout is not set, set timeout to $pnew
   echo "$pnew" >$pfil
   cp -f $lilofil /tmp/lilo.conf-orig
   grep append $lilofil >/dev/null 2>&1
   if [ $? -eq 0 ]
   then
	# modify the append line to add panic timeout
        # can't use $pnew within sed, so set literal 5
        sed -e 's/append=\"/append="panic=5 /' $lilofil >$tmped 
	cp -f $tmped $lilofil
	# use this method in case something else (console) is also in append
   else
	# not found, so add the append line
	cat - <<%%% >$tmped 
1
/timeout
a
append="panic=$pnew"
.
w
q
%%%
	 ed $lilofil <$tmped >/dev/null
   fi
fi

# Set up the PEF entry to send the BMC LAN Alert for this event.
$pdir/pefconfig >$tmpsel

# --- Dont need to load module, bmc_panic is now linked into the kernel.

echo "done `date`" 

%preun
# before uninstall
echo "Uninstalling Panic Handler feature ..."

%postun
# after uninstall, clean up anything left over
pdir=/usr/share/panicsel
tmped=/tmp/edmk.tmp

rm -rf $pdir  2>/dev/null
#rm -f /usr/local/bin/showsel
#rm -f /usr/local/bin/pefconfig
#rm -f /usr/local/bin/hwreset


%changelog
* Tue Jan 28 2003 Andrew Cress <arcress@users.sourceforge.net> 
- added sensor & fruconfig for panicsel 1.2.8
* Tue Aug  2 2002 Andrew Cress <andrew.r.cress@intel.com> 
- fixed bug 793 (dont need Require:ipmidrvr) for panicsel 1.2.2
* Tue Jul  2 2002 Andrew Cress <andrew.r.cress@intel.com> 
- fixed bug 555 in showsel for panicsel 1.2.1
* Fri May 10 2002 Andrew Cress <andrew.r.cress@intel.com> 
- fixed bug 504 in pefconfig for panicsel 1.1.5
* Thu Apr 11 2002 Andrew Cress <andrew.r.cress@intel.com> 
- updated pathnames for panicsel 1.1.4, some cleanup
* Mon Mar 18 2002 Andrew Cress <andrew.r.cress@intel.com> 
- updated for 1.1.3-2, added checking for grub vs. lilo to .spec
* Tue Mar 12 2002 Andrew Cress <andrew.r.cress@intel.com> 
- updated for 1.1.3, added source rpm, changed license, etc.
* Thu Jan 31 2002 Andrew Cress <andrew.r.cress@intel.com> 
- updated for 1.1.0-2, changed selpef to pefconfig
* Thu Jan 25 2002 Andrew Cress <andrew.r.cress@intel.com> 
- updated for 1.1.0, changed to ipmidrvr rather than isc dependency
* Thu Jan 16 2002 Andrew Cress <andrew.r.cress@intel.com> 
- updated for 1.1.0, added hwreset utility
* Thu Dec 14 2001 Andrew Cress <andrew.r.cress@intel.com> 
- updated for 1.0.0, man page updates
* Thu Nov 19 2001 Andrew Cress <andrew.r.cress@intel.com> 
- updated for 0.9.0, uses new OSS bmc_panic, so don't install module.
* Thu Nov 13 2001 Andrew Cress <andrew.r.cress@intel.com> 
- updated for 0.8.5, add "Requires: isc" (#32), hide selpef output (#38)
* Thu Nov  8 2001 Andrew Cress <andrew.r.cress@intel.com> 
- updated for 0.8.4, eliminate "file exists" messages by fixing removal
* Thu Oct 25 2001 Andrew Cress <andrew.r.cress@intel.com> 
- updated for 0.8.2, run selpef (objdump:applypatch gives bogus warning)
* Thu Oct 25 2001 Andrew Cress <andrew.r.cress@intel.com> 
- updated for 0.8.2, run selpef (objdump:applypatch gives bogus warning)
* Wed Oct 24 2001 Andrew Cress <andrew.r.cress@intel.com> 
- created panicsel package 0.8.1 without kbuild
* Tue Oct 23 2001 Andrew Cress <andrew.r.cress@intel.com> 
- created panicsel package 0.8.0
