#! /bin/bash
#
#This is the test harness for watchdog timer
#Created by #Created by Xiaofeng Ling Xiaofeng.Ling@intel.com
#Modified 1/28/02 - Changed to take an input parameter
#                   for location of wdtTest (JF)
#Modified 2/12/02 - Changed to add full path to some commands so they can be run
#                   from cron.
#Modified 6/18/02 - Changed to support the new combined ipmi driver
#Modified 23/12/03 - Changed to support open ipmi


IPMIMODULE=ipmi_watchdog
IPMISUB=ipmi
iMargin=
iPre=
iAction=
iPreAction=
iIoAddr=0
iRefresh=5
iTotalTime=21
iWorkingDir=$PWD
iModuleUsed=0
declare -i nRetVal
nRetVal=0
usage()
{
		echo "USAGE: $0 -a action -r pre_action -d refresh-time -m margin-time -p pre-time -t total-runtime -w working-dir -o pre_opt i ioaddr"
		echo "
              action:     0 - noaction
                          1 - restart
                          2 - shutdown
                          3 - power cycle
              pre-action: 0 - noaction
                          1 - SMI
                          2 - NMI
                          3 - Message Interrupt
              pre-op:     0 - none
                          1 - panic
                          2 - give data"
	exit -1
}
 
#Get Parameter
if [ $# -lt 2 ];then
	usage;
fi
while getopts ":a:r:d:m:p:t:w:i:o" opt;
do
  case $opt in
	a) iAction=$OPTARG ;;
	r) iPreAction=$OPTARG;;
	d) iRefresh=$OPTARG ;;
	m) iMargin=$OPTARG ;;
	p) iPre=$OPTARG ;;
	t) iTotalTime=$OPTARG ;;
        w) iWorkingDir=$OPTARG ;;
	i) iIoAddr=$OPTARG;;
	o) iPreOp=$OPTARG;;
	\?) 
		usage;;
 esac	
done
#show parameters
#echo "action=$iAction, pre_action=$iPreAction wdt_margin=$iMargin, wdt_pre=$iPre,pre_op=$iPreOp"
#echo "refresh time is:$iRefresh, total time is:$iTotalTime"

if [ ! -e /dev/watchdog ];then
   echo "creat /dev/watchdog nod now.."
   mknod /dev/watchdog c 10 130
fi
kernel_version=`uname -a|awk '{print $3}'`
driver_path="/lib/modules/$kernel_version/kernel/drivers/char"

if [ -e $driver_path/$IPMISUB/$IPMIMODULE.o ];then
   driver_path=$driver_path/$IPMISUB
fi
if [ ! -e $driver_path/$IPMIMODULE.o ];then  
   echo "Can not find $IPMIMODULE driver in $driver_path"  
   echo "$IPMIMODULE driver may not have been installed"
   exit -1
fi

#install the module
if cat /proc/modules | grep -e $IPMIMODULE > /dev/null 
then
   iModuleUsed=1
   REFCOUNT=`lsmod|grep "^$IPMIMODULE" |awk '{print $3}'`
   if [ $REFCOUNT -gt 0 ];then
	iModuleUsed=2
		sleep 2
   		echo "IPMI module already been used by other application"
		exit -1
   fi
   rmmod $IPMIMODULE
   if [ ! $? -eq 0 ];then
	echo "Can not remove ipmi driver module before setting watchdog timer"
	exit -1
   fi
fi
sleep 1   

Action=(none reset power_off power_cycle)
PreAction=(pre_none pre_smi pre_nmi pre_int)
PreOp=(preop_none preop_panic preop_give_data)
if [ $IPMIMODULE == ipmi_comb ];then
	/sbin/insmod $driver_path/$IPMIMODULE.o action=$iAction pre_action=$iPreAction margin=$iMargin pre_margin=$iPre io_addr=$iIoAddr 
elif [ $IPMIMODULE == ipmi_watchdog ];then
	if cat /proc/modules | grep -e ipmi_comb > /dev/null 
	then
		rmmod ipmi_comb
	fi
	/sbin/modprobe ipmi_kcs_drv
	/sbin/modprobe $IPMIMODULE action=${Action[$iAction]}  preaction=${Preaction[$iPre]} timeout=$iMargin pretimeout=$iPretimeout preop=$iPreOp
fi
if [ $? -eq 0 ]
    then
       nRetVal=$nRetVal+0
else
    echo "Can not insmod $IPMIMODULE" 
	exit -1
fi
sleep 1

iMargin=${iMargin:-60}
iPre=${iPre:-1}
iPreAction=${iPreAction:-0}
iAction=${iAction:-0x03}
#Run the test case
#echo "Now try to open watchdog device and test it"
$iWorkingDir/testwdt $iRefresh $iTotalTime $iMargin $iPre $iAction $iPreAction
if [ $? -eq 0 ]
then
   nRetVal=$nRetVal+0
else
   nRetVal=$nRetVal+1
fi


#remove the module
if [ $iModuleUsed -eq 0 ];then
	sleep 2
    /sbin/rmmod $IPMIMODULE
fi
if [ $? -eq 0 ]
then
   nRetVal=$nRetVal+0
else
   nRetVal=$nRetVal+1
fi
exit $nRetVal
